Crate axerrno

source ·
axerrno

Crates.io Docs.rs CI

Generic error code representation.

It provides two error types and the corresponding result types:

Macros

  • Convenience method to construct an Err(AxError) type while printing a warning message.
  • Convenience method to construct an AxError type while printing a warning message.
  • Ensure a condition is true. If it is not, return from the function with an error.

Enums

  • The error type used by ArceOS.
  • Linux specific error codes defined in errno.h.

Type Aliases